bayespy.inference.vmp.transformations.RotateGaussian.rotate
===========================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotateGaussian.rotate